package gocnjhelper

import (
	"os"
	"time"

	"github.com/rs/zerolog"
	"github.com/rs/zerolog/log"
)

func InitLogger(debug bool, colorizedOutput bool, rabbitMqLogging bool) {
	zerolog.TimeFieldFormat = zerolog.TimeFormatUnix

	if debug {
		zerolog.SetGlobalLevel(zerolog.DebugLevel)
	} else {
		zerolog.SetGlobalLevel(zerolog.InfoLevel)
	}

	if colorizedOutput {
		log.Logger = log.Output(zerolog.ConsoleWriter{Out: os.Stderr, TimeFormat: time.TimeOnly})
	}
}

func LogInfo(msg string) {
	log.Info().Msg(msg)
}

func LogInfof(format string, v ...interface{}) {
	log.Info().Msgf(format, v)
}

func LogDebug(msg string) {
	log.Debug().Msg(msg)
}

func LogDebugf(format string, v ...interface{}) {
	log.Debug().Msgf(format, v)
}

func LogError(msg string) {
	log.Error().Msg(msg)
}

func LogErrorf(format string, v ...interface{}) {
	log.Error().Msgf(format, v)
}

func LogFatal(msg string) {
	log.Fatal().Msg(msg)
}

func LogFatalf(format string, v ...interface{}) {
	log.Fatal().Msgf(format, v)
}
